coords: Retrieve the coordinates of a colour vector

coordsR Documentation

Retrieve the coordinates of a colour vector

Description

This function retrieves the coordinates of a colour vector's elements, within whatever space it is currently defined.

Usage

coords(x, ...)

Arguments

x

An R object.

...

Additional arguments to methods.

Value

A matrix giving colour coordinates in the relevant space, one colour per row. Columns are typically named.

Author(s)

Jon Clayden code@clayden.org

Examples

coords("red")

shades documentation built on July 3, 2026, 1:07 a.m.