| swatch | R Documentation |
This function provides a simple visualisation of a colour series as a series of boxes against the specified background colour. If the input has more than one dimension then the boxes will be arranged in a grid (flattening further dimensions after the second).
swatch(x, bg = "white", border = "grey50", cex = 0.7, font = 2, ...)
x |
One or more colours, in any suitable form (see |
bg |
A background colour. |
border |
The border colour to draw around each box. |
cex |
The font size to use for labelling named shades. |
font |
The font weight to use for labelling named shades, in the sense
of |
... |
Additional arguments (currently unused). |
Jon Clayden code@clayden.org
par()
swatch(c("red", "green", "blue"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.